<template>
	<div class="section-main-container layout-padding">
		<div class="section-main-padding layout-padding-auto layout-padding-view">
			<div class="section-user-search mb15">
				<el-row>
					<div class="alerttips"><el-alert title="对账数据生成：每天凌晨定时产生前一日的对账数据。" type="warning" show-icon :closable="false" />
					</div>
				</el-row>
				<el-row>
					<el-form :inline="true" :model="state.tableData.param" class="demo-form-inline" label-position="left"
						size="default" @submit.prevent>
						<!-- <el-form-item label="交易类型">
							<el-select v-model="state.tableData.param.bank_trade_type" clearable>
								<el-option value="1" label="订单支付"></el-option>
							</el-select>
						</el-form-item> -->
						<el-form-item label="交易日期">
							<el-date-picker v-model="state.tableData.param.startDateEndArr" type="daterange" range-separator="-"
								start-placeholder="开始日期" end-placeholder="结束日期" format="YYYY-MM-DD" value-format="YYYY-MM-DD" />
						</el-form-item>
						<el-form-item label="资金流向">
							<el-select v-model="state.tableData.param.fundFlowType" clearable>
								<el-option value="1" label="收入"></el-option>
								<el-option value="2" label="支出"></el-option>
							</el-select>
						</el-form-item>
						<el-form-item label="对方户名">
							<el-input v-model="state.tableData.param.accountName" clearable />
						</el-form-item>
						<el-form-item>
							<el-button type="primary" @click="getTableData">查询</el-button>
							<el-button type="default" @click="resetgetTableData">重置</el-button>
						</el-form-item>
					</el-form>
				</el-row>
				<el-row>
					<el-button type="primary" size="default" @click="exportData">导出为excel文件</el-button>
				</el-row>
			</div>
			<el-row>
				<section class="totalNumber">
					<span>总笔数：{{ dataResItem.totalCount }}笔</span> | <span>总金额：{{ dataResItem.sumAmount }}元</span> | <span
						class="successColor">成功笔数：{{ dataResItem.successCount }}笔</span> | <span class="successColor">成功金额：{{
							dataResItem.successAmount }}元</span> | <span class="failColor">失败笔数：{{ dataResItem.errorCount }}笔</span> |
					<span class="failColor">失败金额：{{ dataResItem.errorAmount }}元</span> | <span class="ProcessingColor">处理中笔数：{{
						dataResItem.processingCount }}笔</span> |
					<span class="ProcessingColor">处理中金额：{{ dataResItem.processingAmount }}元</span>
				</section>
			</el-row>
			<el-table :data="state.tableData.data" v-loading="state.tableData.loading" style="width: 100%">
				<el-table-column prop="tradeSerialNo" label="交易流水号" show-overflow-tooltip></el-table-column>
				<!-- <el-table-column prop="bankTradeType" label="交易类型" show-overflow-tooltip></el-table-column> -->
				<el-table-column prop="tradeStatus" label="交易状态" show-overflow-tooltip></el-table-column>
				<el-table-column prop="tradeStartTime" label="交易订单创建时间" width="200" show-overflow-tooltip></el-table-column>
				<el-table-column prop="tradeAmount" label="交易金额" show-overflow-tooltip></el-table-column>
				<el-table-column prop="expendAccountName" label="出账方户名" show-overflow-tooltip></el-table-column>
				<el-table-column prop="expendAccountNo" label="出账方账号" show-overflow-tooltip></el-table-column>
				<el-table-column prop="expendBank" label="出账方银行简称" show-overflow-tooltip></el-table-column>
				<el-table-column prop="incomeAccountName" label="入账方户名" show-overflow-tooltip></el-table-column>
				<el-table-column prop="incomeAccountNo" label="入账方账号" show-overflow-tooltip></el-table-column>
				<el-table-column prop="incomeBank" label="入账方银行简称" show-overflow-tooltip></el-table-column>
				<el-table-column prop="remark" label="交易备注" show-overflow-tooltip></el-table-column>
				<el-table-column label="操作" width="100" fixed="right">
					<template #default="scope">
						<el-button size="small" text type="primary" @click.prevent="onOpenDown('detail', scope.row)">电子回单</el-button>
					</template>
				</el-table-column>
			</el-table>
			<el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="mt15"
				:pager-count="5" :page-sizes="[10, 20, 30, 100, 200, 300, 1000]"
				v-model:current-page="state.tableData.param.pageNumber" background
				v-model:page-size="state.tableData.param.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="state.tableData.total">
			</el-pagination>
		</div>
		<ConfigDialog ref="configDialogRef" @refresh="getTableData()" />
	</div>
</template>

<script setup lang="ts" name="targetData">
import { defineAsyncComponent, reactive, onMounted, ref, inject } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api'
import { useRoute, useRouter, onBeforeRouteUpdate } from 'vue-router';
import { refreshBtnView } from '/@/components/refreshView'
// 引入组件
const ConfigDialog = defineAsyncComponent(() => import('./dialog.vue'));
// 定义变量内容
const route = useRoute()
const configDialogRef = ref();
const state = reactive({
	tableData: {
		data: [],
		total: 0,
		loading: false,
		param: {
			startDateEndArr: [] as string[],
			startDateEndArrRest: [] as string[],
			startDate: '',
			endDate: '',
			// bank_trade_type: '',
			fundFlowType: '2',
			accountName: '',
			pageNumber: 1,
			pageSize: 10,
		},
	},
});
const dataResItem = ref({
	totalCount: 0,
	sumAmount: 0,
	successCount: 0,
	successAmount: 0,
	errorCount: 0,
	errorAmount: 0,
	processingCount: 0,
	processingAmount: 0
})
// 初始化表格数据
const getTableData = () => {
	state.tableData.loading = true;
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.startDateEndArr.length) {
		obj.startDate = (obj.startDateEndArr)[0]
		obj.endDate = (obj.startDateEndArr)[1]
	}
	delete obj.startDateEndArr
	delete obj.startDateEndArrRest
	ConfigApi().reconciliationApi(obj).then(response => {
		console.log('response查询', response)
		if (response.code == 200) {
			state.tableData.data = response.data.pageInfo.list
			state.tableData.total = response.data.pageInfo.total;
			dataResItem.value = response.data;//获取总笔试各个字段
		}
	}).catch((e) => { })
	setTimeout(() => {
		state.tableData.loading = false;
	}, 500);
};
const resetgetTableData = () => {
	let obj = {
		startDateEndArr: state.tableData.param.startDateEndArrRest,
		startDateEndArrRest: [],
		startDate: '',
		endDate: '',
		// bank_trade_type: '',
		fundFlowType: '2',
		accountName: '',
		pageNumber: 1,
		pageSize: 10,
	}
	state.tableData.param = reactive(obj)
	getTableData()
};
// 打开新增弹窗
const onOpenAdd = (type: string) => {
	configDialogRef?.value.openDialog(type);
};
// 打开修改弹窗
const onOpenEdit = (type: string, row: Object) => {
	console.log(row)
	configDialogRef?.value.openDialog(type, row);
};
// 删除
const onRowDel = (row: RowRoleType) => {
	ElMessageBox.confirm(`此操作将永久删除：“${row.roleName}”，是否继续?`, '提示', {
		confirmButtonText: '确认',
		cancelButtonText: '取消',
		type: 'warning',
	})
		.then(() => {
			getTableData();
			ElMessage.success('删除成功');
		})
		.catch(() => { });
};
// 分页改变
const onHandleSizeChange = (val: number) => {
	state.tableData.param.pageSize = val;
	getTableData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
	state.tableData.param.pageNumber = val;
	getTableData();
};
//刷新当前列表
// const reload = inject('reload')//子接收
const refreshBtn = () => {
	refreshBtnView(route)
}
//导出excel
const exportData = () => {
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.startDateEndArr.length) {
		obj.startDate = (obj.startDateEndArr)[0]
		obj.endDate = (obj.startDateEndArr)[1]
	}
	delete obj.startDateEndArr
	delete obj.startDateEndArrRest
	delete obj.pageNumber
	delete obj.pageSize
	ConfigApi().exportReconciliationApi(obj).then(response => {
		const content = response;
		const blob = new Blob([content.data]);
		const fileName = `对账数据.xls`;
		if ("download" in document.createElement("a")) {
			// 非IE下载
			const elink = document.createElement("a");
			elink.download = fileName;
			elink.style.display = "none";
			elink.href = URL.createObjectURL(blob);
			document.body.appendChild(elink);
			elink.click();
			URL.revokeObjectURL(elink.href); // 释放URL 对象
			document.body.removeChild(elink);
		} else {
			// IE10+下载
			navigator.msSaveBlob(blob, fileName);
		}
	}).catch((error) => { })
}
//电子回单下载
const onOpenDown = (type, row) => {
	console.log(row)
	let tradeFlowNo = row.id
	let obj = {
		tradeFlowNo: tradeFlowNo
	}
	ConfigApi().tradevoucherDownApi(obj).then(response => {
		console.log(response)
		if (response.data) {
			window.open(response.data)
		}
	})
}
// 页面加载时
onMounted(() => {
	//获取近天的日期
	var tempDate = new Date() // 获取今天的日期
	let nowDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	tempDate.setDate(tempDate.getDate() - 6) // 今天的前N天的日期，N自定义
	var endDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	console.log('endDate', endDate)

	state.tableData.param.startDateEndArr = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	state.tableData.param.startDateEndArrRest = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	getTableData();
});
</script>

<style scoped lang="scss">
.section-main-container {
	.section-main-padding {
		padding: 15px;

		.el-table {
			flex: 1;
		}

		.alerttips {
			margin: 10px 0 20px 0;
			width: 100%
		}

		.totalNumber {
			padding: 20px 0;
			color: rgba(0, 0, 0, .65);

			.successColor {
				color: green
			}

			.failColor {
				color: red
			}

			.ProcessingColor {
				color: orange
			}
		}
	}
}
</style>
